############################################################
# Version 1.01
# Date Created: 2018-05-15
# Last Update:  2018-05-16
# https://www.neoprime.io
# Copyright (c) 2018, NeoPrime, LLC
############################################################

""" Automating with Python and the Alibaba Cloud SDKs """

import os
import sys
import platform
import configparser

def getHomeDir():
	dir = ""

	if platform.system() == "Windows":
		dir = os.environ['HOMEDRIVE'] + os.environ['HOMEPATH']
		pass
	else:
		dir = os.environ['HOME']
		pass

	return dir

def getCredentialsPath():
	dir = getHomeDir()

	dir = dir + "\\.aliyuncli/credentials"

	return dir

def getConfigurePath():
	dir = getHomeDir()

	dir = dir + "\\.aliyuncli/configure"

	return dir

def loadConfigureFile(path, cred, profileName='default'):
	if os.path.exists(path) is False:
		print("Error: Cannot load configure file from file")
		print("File: ", path)
		return False;

	config = configparser.ConfigParser()
	config.read(path)

	try:
		cred['Region'] = config[profileName]['region']

	except Exception as ex:
		print("Exception: ", ex)
		print("Error: Cannot load configure profile name: ", profileName)
		return False;

	return cred;


def loadCredentialsFile(path, profileName='default'):
	cred = {
		'AccessKey': '',
		'AccessKeySecret': '',
		'Region': ''
		}

	if os.path.exists(path) is False:
		print("Error: Cannot load credentials file from file")
		print("File: ", path)
		return False;

	config = configparser.ConfigParser()
	config.read(path)

	try:
		cred['AccessKey'] = config[profileName]['aliyun_access_key_id']
		cred['AccessKeySecret'] = config[profileName]['aliyun_access_key_secret']

	except Exception as ex:
		print("Exception: ", ex)
		print("Error: Cannot load credential profile name: ", profileName)
		return False;

	return cred;

def LoadCredentials(profileName='default'):
	cred_file = getCredentialsPath()
	conf_file = getConfigurePath()

	cred = loadCredentialsFile(cred_file, profileName)

	if cred is False:
		return False;

	loadConfigureFile(conf_file, cred, profileName)

	return cred;
